@@ -4,21 +4,19 @@
 # @Email  : 877362867@qq.com
 # @Date   : 2020/06/02 16:06
 
-import itertools
+from pyxllib.prog.pupil import check_install_package
+
+check_install_package('fitz', 'PyMuPdf>=1.18.17')
+
 import json
 import os
 import pprint
 import re
-import subprocess
 
-try:
-    import fitz
-except ModuleNotFoundError:
-    subprocess.run(['pip3', 'install', 'PyMuPdf>=1.18.17'])
-    import fitz
+import fitz
 
 from pyxllib.prog.newbie import round_int, RunOnlyOnce, decode_bitflags
-from pyxllib.prog.pupil import DictTool, EnchantBase
+from pyxllib.prog.pupil import DictTool, EnchantBase, EnchantCvt
 from pyxllib.algo.newbie import round_unit
 from pyxllib.algo.pupil import get_number_width
 from pyxllib.file.specialist import File, Dir, writefile, get_etag
@@ -94,11 +92,8 @@ class FitzDoc:
 
     def to_docx(self, docx_file=None):
         """ pdf转docx """
-        try:
-            from pdf2docx import parse
-        except ModuleNotFoundError:
-            subprocess.run('pip3 install pdf2docx')
-            from pdf2docx import parse
+        check_install_package('pdf2docx')
+        from pdf2docx import parse
 
         pdf_file = self.src_file
 
@@ -139,8 +134,8 @@ class EnchantFitzPage(EnchantBase):
         names = cls.check_enchant_names([fitz.fitz.Page])
         cls_methods = {'parse_flags'}
 
-        cls._enchant(fitz.fitz.Page, cls_methods, 'staticmethod2classmethod')
-        cls._enchant(fitz.fitz.Page, names - cls_methods, 'staticmethod2objectmethod')
+        cls._enchant(fitz.fitz.Page, cls_methods, EnchantCvt.staticmethod2classmethod)
+        cls._enchant(fitz.fitz.Page, names - cls_methods)
 
     @staticmethod
     def get_svg_image2(_self, scale=1):
