@@ -13,7 +13,5 @@
 
 改了底层标准库一些功能，修复一些bug，或者提升功能兼容性、强度
 
-zipfile: py3.6在windows处理zip，解压中文文件会乱码，要改一个编码
-    这个在py3.8中也没有修复，但是py3.8的zipfile更新了不少内容，有时间我要重新整理过来
 onepy: 做了些中文注解，其他修改了啥我也忘了~~可能是有改源码功能的
 """
